==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/id/admin/users/general.php <==
<?php


return array(
    'activated_help_text' => 'Pengguna ini dapat masuk',
    'activated_disabled_help_text' => 'Anda tidak dapat menyunting status aktivasi akun anda sendiri.',
    'assets_user'       => 'Aset pada :name',
    'bulk_update_warn'	=> 'Anda akan mengedit properti dari: user_count pengguna. Harap perhatikan bahwa Anda tidak dapat mengubah atribut pengguna Anda sendiri menggunakan formulir ini, dan harus melakukan pengeditan kepada pengguna Anda sendiri satu per satu.',
    'bulk_update_help'	=> 'Formulir ini memungkinkan Anda untuk memperbarui beberapa pengguna sekaligus. Isi saja bidang yang perlu Anda ubah. Setiap bidang yang dikosongkan akan tetap tidak berubah.',
    'current_assets'    => 'Aset ini untuk pengguna ini',
    'clone'             => 'Klon pengguna',
    'contact_user'      => 'Kontak :name',
    'edit'              => 'Sunting Pengguna',
    'filetype_info'     => 'Jenis berkas diizinkan adalah png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, dan rar.',
    'history_user'      => 'Riwayat untuk :name',
	'info'				=> 'Info',
    'restore_user'		=> 'Klik di sini untuk mengembalikannya.',
    'last_login'        => 'Terakhir masuk',
    'ldap_config_text'  => 'Konfigurasi LDAP terdapat di Admin > Pengaturan. Jika lokasi di pilih, maka akan di impor untuk semua pengguna.',
    'print_assigned'    => 'Cetak Semua Ditugaskan',
    'software_user'     => 'Perangkat lunak pada :name',
    'send_email_help'   => 'You must provide an email address for this user to send them credentials. Emailing credentials can only be done on user creation. Passwords are stored in a one-way hash and cannot be retrieved once saved.',
    'view_user'         => 'Lihat pengguna: name',
    'usercsv'           => 'Berkas CSV',
    'two_factor_admin_optin_help' => 'Pengaturan admin Anda saat ini memungkinkan penegakan dua faktor otentikasi selektif.',
    'two_factor_enrolled' => 'Perangkat 2FA Terdaftar',
    'two_factor_active'   => '2FA Aktif',
    );

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/id/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Pengguna ini dapat masuk',
    'activated_disabled_help_text' => 'Anda tidak dapat menyunting status aktivasi akun anda sendiri.',
    'assets_user'       => 'Aset pada :name',
    'bulk_update_warn'	=> 'Anda akan mengedit properti dari: user_count pengguna. Harap perhatikan bahwa Anda tidak dapat mengubah atribut pengguna Anda sendiri menggunakan formulir ini, dan harus melakukan pengeditan kepada pengguna Anda sendiri satu per satu.',
    'bulk_update_help'	=> 'Formulir ini memungkinkan Anda untuk memperbarui beberapa pengguna sekaligus. Isi saja bidang yang perlu Anda ubah. Setiap bidang yang dikosongkan akan tetap tidak berubah.',
    'current_assets'    => 'Aset ini untuk pengguna ini',
    'clone'             => 'Klon pengguna',
    'contact_user'      => 'Kontak :name',
    'edit'              => 'Sunting Pengguna',
    'filetype_info'     => 'Jenis berkas diizinkan adalah png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, dan rar.',
    'history_user'      => 'Riwayat untuk :name',
    'info'				=> 'Info',
    'restore_user'		=> 'Klik di sini untuk mengembalikannya.',
    'last_login'        => 'Terakhir masuk',
    'ldap_config_text'  => 'Konfigurasi LDAP terdapat di Admin > Pengaturan. Jika lokasi di pilih, maka akan di impor untuk semua pengguna.',
    'print_assigned'    => 'Cetak Semua Ditugaskan',
    'software_user'     => 'Perangkat lunak pada :name',
    'send_email_help'   => 'Anda harus memberikan alamat email pengguna ini untuk mengirimkan kredensial kepada mereka. Pengiriman email kredensial hanya dapat dilakukan pada pembuatan user. Kata sandi disimpan dalam hash satu arah dan tidak dapat diambil setelah disimpan.',
    'view_user'         => 'Lihat pengguna: name',
    'usercsv'           => 'Berkas CSV',
    'two_factor_admin_optin_help' => 'Pengaturan admin Anda saat ini memungkinkan penegakan dua faktor otentikasi selektif.',
    'two_factor_enrolled' => 'Perangkat 2FA Terdaftar',
    'two_factor_active'   => '2FA Aktif',
    'user_deactivated'  => 'User is de-activated',
    'activation_status_warning' => 'Do not change activation status',
    'group_memberships_helpblock' => 'Only superadmins may edit group memberships.',
    'superadmin_permission_warning' => 'Only superadmins may grant a user superadmin access.',
    'admin_permission_warning' => 'Only users with admins rights or greater may grant a user admin access.',
    'remove_group_memberships' => 'Remove Group Memberships',
    'warning_deletion' => 'WARNING:',
    'warning_deletion_information' => 'You are about to delete the :count user(s) listed below. Super admin names are highlighted in red.',
    'update_user_asssets_status' => 'Update all assets for these users to this status',
    'checkin_user_properties' => 'Check in all properties associated with these users',
];
